@@ -10,6 +10,7 @@ from requests import PreparedRequest, Session, Response
 from requests.status_codes import _codes as status_code
 from textx import metamodel_from_file
 
+from dothttp.parse_models import Allhttp
 from . import eprint, Config, HttpDefBase
 from .curl_utils import to_curl
 from .dsl_jsonparser import json_or_array_to_json
@@ -47,6 +48,7 @@ dothttp_model = metamodel_from_file(dir_path)
 
 
 class RequestBase(HttpDefBase):
+    global_session = Session()
     def __init__(self, args: Config):
         super().__init__(args)
         self._cookie: Union[LWPCookieJar, None] = None
@@ -81,7 +83,7 @@ class RequestBase(HttpDefBase):
         return self._cookie
 
     def get_session(self):
-        session = Session()
+        session = self.global_session
         if not self.args.no_cookie:
             if cookie := self.get_cookie():
                 session.cookies = cookie
@@ -158,7 +160,7 @@ class HttpFileFormatter(RequestBase):
         self.prop_cache = {}
 
     @staticmethod
-    def format(model):
+    def format(model: Allhttp):
         output_str = ""
         for http in model.allhttps:
             new_line = "\n"
@@ -182,7 +184,8 @@ class HttpFileFormatter(RequestBase):
             if payload := http.payload:
                 p = ""
                 mime_type = payload.type
-                if data := payload.data:
+                if payload.data or payload.multi:
+                    data = payload.data or payload.multi[3:-3]
                     if '"' in data and "'" not in data:
                         data = f"'{data}'"
                     elif '"' not in data and "'" in data:
