@@ -370,7 +370,8 @@ class HttpDefBase(BaseModelProcessor):
         # can be short circuted
         if not self.http.payload:
             return Payload()
-        elif data := self.http.payload.data:
+        elif self.http.payload.data or self.http.payload.multi:
+            data = self.http.payload.data or self.http.payload.multi[3:-3]
             content = self.get_updated_content(data)
             mimetype = self.get_mimetype_from_buffer(content,
                                                      self.get_updated_content(self.http.payload.type))
@@ -410,8 +411,7 @@ class HttpDefBase(BaseModelProcessor):
                     multipart_content = open(multipart_content, 'rb')
                     files.append((multipart_key, (multipart_filename, multipart_content, mimetype)))
                 else:
-                    # mimetype = self.get_mimetype_from_buffer(multipart_content, mimetype)
-                    mimetype = None
+                    mimetype = self.get_mimetype_from_buffer(multipart_content, mimetype)
                     files.append((multipart_key, (None, multipart_content, mimetype)))
             return Payload(files=files, header=MULTIPART_FORM_INPUT)
         return Payload()
